==> hplip-3.10.2.tar.xz: hplip-3.10.2/prnt/hpcups/RasterSender.h <==
/*****************************************************************************\
  RasterSender.h : Interface for the RasterSender class

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/

#ifndef RASTERSENDER_H
#define RASTERSENDER_H

#include "CommonDefinitions.h"
#include "Processor.h"
#include "Encapsulator.h"

class RasterSender : public Processor
{
public:
    // installs Header and Connection
    RasterSender (Encapsulator *pEncap);

    ~RasterSender();

    // processor interface ////////////////////////////////////
    bool Process(RASTERDATA* InputRaster=NULL);
    void Flush() { };
    bool NextOutputRaster(RASTERDATA& next_raster) { return false; }   // end of pipeline
    unsigned int GetMaxOutputWidth() { return 0; } // never called
private:
    Encapsulator    *encap;
}; // RasterSender

#endif // RASTERSENDER_H

==> hplip_3.21.2+dfsg1.orig.tar.xz: hplip-3.21.2+dfsg1/prnt/hpcups/RasterSender.h <==
/*****************************************************************************\
  RasterSender.h : Interface for the RasterSender class

  Copyright (c) 1996 - 2015, HP Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of HP nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/

#ifndef RASTERSENDER_H
#define RASTERSENDER_H

#include "CommonDefinitions.h"
#include "Processor.h"
#include "Encapsulator.h"

class RasterSender : public Processor
{
public:
    // installs Header and Connection
    RasterSender (Encapsulator *pEncap);

    ~RasterSender();

    // processor interface ////////////////////////////////////
    bool Process(RASTERDATA* InputRaster=NULL);
    void Flush() { };
    bool NextOutputRaster(RASTERDATA& next_raster) { return false; }   // end of pipeline
    unsigned int GetMaxOutputWidth() { return 0; } // never called
private:
    Encapsulator    *encap;
}; // RasterSender

#endif // RASTERSENDER_H
